@@ -1,11 +1,17 @@
-# author: Scott Gigante <scott.gigante@yale.edu>
-# (C) 2018 Krishnaswamy Lab GPLv2
-
+from . import _patch
 from .version import __version__
-import scprep.io
+
 import scprep.filter
-import scprep.normalize
-import scprep.transform
+import scprep.io
+import scprep.io.hdf5
 import scprep.measure
+import scprep.normalize
 import scprep.plot
+import scprep.reduce
+import scprep.run
 import scprep.sanitize
+import scprep.select
+import scprep.stats
+import scprep.transform
+
+_patch.patch_fill_value()
